#!/bin/sh
# SPDX-License-Identifier: AGPL-3.0-only
# author: xengineering <me@xengineering.eu>

# Samsung Galaxy Tab A 9.7 2015 (tested on LTE variant, Code SM-T555)
export SXMO_DISABLE_LEDS="1"
export SXMO_POWER_BUTTON="0:0:pm8941_pwrkey"
export SXMO_VOLUME_BUTTON="1:1:GPIO_Buttons 0:0:pm8941_resin"
export SXMO_SWAY_SCALE="1.5"
